@@ -15,7 +15,7 @@ class RedisQuerySet(django_models.query.QuerySet):
         print('update', concrete_model, self)
         django_ids_to_update = [django_instance.id for django_instance in self]
         data_to_update = redis_root.get(self.model, django_id__in=django_ids_to_update)
-        print(f'now data to update {self.model:', len(data_to_update))
+        print(f'now data to update {self.model}:', len(data_to_update))
         redis_root.update(self.model, data_to_update, **kwargs)
         print(f'now redis {self.model}:', redis_root.get(self.model))
         return self
